@@ -105,11 +105,11 @@ for(f=0;f<strlen(str);f++)
     {
     int tmp;
     
-    /* print an ellipsis... well, three dots :-) */
+    /* print an ellipsis... well, three^H^H^H^H^Htwo dots :-) */
     /* blast the width restriction to stop possible infinite recursion */
     tmp=stop_after_this_x;
     set_max_text_width(NO_CLIP_FONT);
-    a+=vgadrawtext(a,y,siz,"...");
+    a+=vgadrawtext(a,y,siz,"..");
     stop_after_this_x=tmp;
     /* now give up */
     break;
@@ -118,7 +118,7 @@ for(f=0;f<strlen(str);f++)
   
   /*** 1st step: cover some common occurances ***/
   if(!go_through_the_motions)   /* only draw it if we really want to */
-  
+    {
     if(strchr("abdgopq68",c)!=NULL)   /* common circle position */
       fontcircle(a+s1,b+s3,siz);
     else
@@ -135,7 +135,7 @@ for(f=0;f<strlen(str);f++)
       if(strchr("BDEFHKLMNPR",c)!=NULL)
         vga_drawline(a,b,a,b+s4);
       }
-
+    }
 
   /*** 2nd step: fill in rest - this is the *really* long, messy bit :-) ***/
   
@@ -543,8 +543,8 @@ fontoy=fontinfo_ptr->oy;
 /* m_ellipsis_size is the size that an ellipsis will take up, plus the
  * widest possible letter (which we assume is M).
  */
-m_ellipsis_size=3*(widthadd+fontdat[fonttbl['.'-32]+4])+
-		   widthadd+fontdat[fonttbl['M'-32]+4];
+m_ellipsis_size=2*(widthadd+fontdat[fonttbl['.'-32]+4])+
+		   widthadd+fontdat[fonttbl['m'-32]+4];
 
 for(f=0;f<strlen(str);f++)
   {
@@ -552,11 +552,11 @@ for(f=0;f<strlen(str);f++)
     {
     int tmp;
     
-    /* print an ellipsis... well, three dots :-) */
+    /* print an ellipsis... well, three^H^H^H^H^Htwo dots :-) */
     /* blast the width restriction to stop possible infinite recursion */
     tmp=stop_after_this_x;
     set_max_text_width(NO_CLIP_FONT);
-    xpos+=vgadrawtext_bmp(xpos,ypos,siz,"...");
+    xpos+=vgadrawtext_bmp(xpos,ypos,siz,"..");
     stop_after_this_x=tmp;
     /* now give up */
     break;
@@ -612,10 +612,12 @@ for(f=0;f<strlen(str);f++)
               }
         
         if(xrunst!=-1)
+          {
           if(xrunst==x-1)
             vga_drawpixel(xrunst,y);
           else
             vga_drawscansegment(scanbit,xrunst,y,x-xrunst);
+          }
         xrunst=-1;
         }
       }
