@@ -1,5 +1,5 @@
-/* Zgv v2.7 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
- * Copyright (C) 1993-1995 Russell Marks. See README for license details.
+/* zgv 5.2 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
+ * Copyright (C) 1993-2000 Russell Marks. See README for license details.
  *
  * rc_config.h - Defined! the zgv_config structure.
  *                       photographic evidence on page 2. :-)
@@ -9,7 +9,7 @@ struct cfgrgb_tag { int r,g,b; };
 
 struct zgv_config
   {
-  int videomode,zoom,vkludge,jpeg24bit,jpegspeed;
+  int videomode,zoom,zoom_reduce_only,vkludge,jpeg24bit,jpegspeed;
   int jpegindexstyle;  /* 0=v. fast, 1=fast, 2=normal, 3=slow (as in <=v2.7) */
   int centreflag,blockcursor,thicktext;
   int betterpgm;  /* grinds PGM to 24-bit internally allowing 256 shades */
@@ -21,8 +21,7 @@ struct zgv_config
   int repeat_timer,tag_timer;
   int revert,revert_orient,fakecols,selecting;
   int fs16col;
-  int viewer16col;
-  int fullsel;
+  int viewer16col,fastdither16col;
   int echotagged;
   int forgetoldpos;
   int linetext;
@@ -34,9 +33,13 @@ struct zgv_config
   int mousekludge;
   int mousescale;
   int stupid_gnu_verbosity;
-  int hicontrol;
   int fs_startmode;
   int bc_order_rev;
+  int xzgvkeys;
+  int automodefit;
+  double initial_picgamma;
+  int fsmagic;
+  int black_bg;
   
   int brightness;
   double contrast;
@@ -48,6 +51,7 @@ struct zgv_config
   int loop;		/* loop forever in slideshow */
   int svgalib_mouse;	/* whether we should try using mouse or not */
   
-  char cmd[1024];	/* alternative command to run instead of viewing */
   int errignore;
+
+  int pcdres;
   };
